@@ -2,7 +2,14 @@ import time  # datetime may have more precision
 
 from .clients.slack import SlackTelemeter
 from .clients.pagerduty import PagerDutyTelemeter
-from .clients.statsd_ import StatsdTelemeter
+try:
+    from .clients.statsd_ import StatsdTelemeter
+except ImportError:
+    pass
+try:
+    from .clients.datadog import DataDogStatsdTelemeter
+except ImportError:
+    pass
 from .telemeter import Telemeter
 
 # backwards compat
